MagicVaultService class
The Magic Vault Service.
Provides a secure, hardware-backed storage for sensitive data using FlutterSecureStorage.
- Implementers
Constructors
- MagicVaultService()
- MagicVaultService.forTesting()
- Named constructor for testing — skips FlutterSecureStorage initialisation.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
flush(
) → Future< void> - Flush all values from the vault.
-
get(
String key) → Future< String?> - Retrieve a value from the vault.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
put(
String key, String value) → Future< void> - Store a value in the vault.
-
remove(
String key) → Future< void> - Remove a value from the vault.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited